@@ -2,21 +2,22 @@
 NULL
 
 # reg_custom_units {{{
+# nocov start
 reg_custom_units <- function () {
     tryCatch(
         {
-            if (utils::packageVersion("units") < 0.7) {
-                units::install_symbolic_unit("person")
-                units::install_symbolic_unit("dollar")
-                units::install_symbolic_unit("thousandths")
-                units::install_conversion_constant("Wh", "J", 3.6E3)
-                units::install_conversion_constant("inH2O", "inch_H2O_39F", 1)
+            if (utils::packageVersion("units") < "0.7-0") {
+                getExportedValue("units", "install_symbolic_unit")("person")
+                getExportedValue("units", "install_symbolic_unit")("dollar")
+                getExportedValue("units", "install_symbolic_unit")("thousandths")
+                getExportedValue("units", "install_conversion_constant")("Wh", "J", 3.6E3)
+                getExportedValue("units", "install_conversion_constant")("inH2O", "inch_H2O_39F", 1)
             } else {
-                units::install_unit("person")
-                units::install_unit("dollar")
-                units::install_unit("thousandths")
-                units::install_unit("Wh", "3.6E3 J")
-                units::install_unit("inH2O", "1 inch_H2O_39F")
+                getExportedValue("units", "install_unit")("person")
+                getExportedValue("units", "install_unit")("dollar")
+                getExportedValue("units", "install_unit")("thousandths")
+                getExportedValue("units", "install_unit")("Wh", "3.6E3 J")
+                getExportedValue("units", "install_unit")("inH2O", "1 inch_H2O_39F")
             }
             TRUE
         },
@@ -24,6 +25,7 @@ reg_custom_units <- function () {
         error = function (e) NULL
     )
 }
+# nocov end
 # }}}
 
 # FIELD_UNIT_TABLE {{{
