@@ -18,6 +18,19 @@ copy_example <- function (ver = 8.8) {
     list(idf = path_idf, epw = path_epw)
 }
 
+copy_eplus_example <- function(ver, file, dir = tempdir()) {
+    path <- path_eplus_example(ver, file, strict = TRUE)
+    dest <- normalizePath(file.path(dir, basename(path)), mustWork = FALSE)
+
+    flag <- file.copy(path, dest, overwrite = TRUE, copy.mode = TRUE, copy.date = TRUE)
+
+    if (any(!flag)) {
+        stop(sprintf("Failed to copy file from '%s' to '%s'.", path[!flag], dest[!flag]))
+    }
+
+    dest
+}
+
 clean_tempdir <- function () {
     unlink(list.files(tempdir(), full.names = TRUE), force = TRUE)
 }
